Easy-docx
==========

Python library forked from  `python-docx <//github.com/python-openxml/python-docx/>`_.

The main purpose of the fork was to add implementation for comments and footnotes to the library

Installation
------------

Use the package manager `pip <//pypi.org/project/easy-docx/>`_ to install easy-docx.


`pip install easy-docx`
